#!/sbin/openrc-run
name="CollabNet router"

supervisor="supervise-daemon"

command="/home/collabvm/qemu/bin/qemu-system-x86_64"

# added vhost & disk speed limits, to hopefully keep disk thrashing down
command_args="
    -name CollabNet,process=collabnet -accel kvm -M q35 -cpu host,hv_relaxed,hv_spinlocks=0x1fff,hv_vapic,hv_time -smp cores=8 -m 8G -mem-prealloc
    -rtc base=localtime,clock=vm
    -monitor telnet:127.0.0.1:6016,server,nowait
    -netdev tap,ifname=ktalpine-wan,script=/etc/qemu-ifup,downscript=/etc/qemu-ifdown,vhost=on,id=cnetwan
    -netdev tap,ifname=ktalp-lan,script=/etc/qemu-ifup,downscript=/etc/qemu-ifdown,vhost=on,id=cnetlan
    -device virtio-net-pci,netdev=cnetwan,mac=c0:11:ab:69:41:fe
    -device virtio-net-pci,netdev=cnetlan,mac=c0:11:ab:69:41:03
    -drive file=max2.img,if=virtio,cache=writeback,format=raw,bps=50000000,bps_max=100000000
    -vga std
    -vnc localhost:60"

command_background="yes"

supervise_daemon_args="-D 120 --chdir /opt/collabnet --stdout /var/log/collabnet/vm.log --stderr /var/log/collabnet/vm.err.log"
pidfile="/run/collabnet.pid"

rc_cgroup_cleanup="yes"

depend() {
	need net
	after netconf
}

# Run a monitor command
monitor_command() {
	echo "$@" | ncat localhost 6016 >/dev/null 2>&1
}

is_running() {
	[ -e "$pidfile" ] && kill -0 "$(cat "$pidfile")" 2>/dev/null
}

stop() {
	# TODO...

	local count=120

	ebegin "Stopping the VM gracefully"
		if is_running && monitor_command "system_powerdown"; then
			while is_running && [ $count -gt 0 ]; do
				sleep 1;
				printf '.'
				count=$((count - 1))
			done
			printf '\n'
		fi

		if [ $count -eq 0 ]; then
			ewarn "Couldn't stop gracefully"
		fi
		supervise_stop
	eend $?

}
